==> nextcloud-22.1.1.tgz: nextcloud/apps/systemtags/l10n/vi.js <==
OC.L10N.register(
    "systemtags",
    {
    "Update" : "Cập nhật",
    "Create" : "Tạo",
    "Select tag …" : "Lựa chọn thẻ",
    "Added system tag {systemtag}" : "Nhãn hệ thống được thêm vào {systemtag}",
    "Added system tag %1$s" : "Đã thêm nhãn hệ thống %1$s",
    "%1$s added system tag %2$s" : "%1$s đã thêm nhãn hệ thống %2$s",
    "{actor} added system tag {systemtag}" : "{actor} đã thêm nhãn hệ thống {systemtag}",
    "Removed system tag {systemtag}" : "Đã xóa nhãn hệ thống {systemtag}",
    "Removed system tag %1$s" : "Đã xóa nhãn hệ thống %1$s",
    "%1$s removed system tag %2$s" : "%1$s đã xóa nhãn hệ thống %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} đã xóa nhãn {systemtag}",
    "You created system tag %1$s" : "Bạn đã tạo nhãn %1$s",
    "You created system tag {systemtag}" : "Bạn đã tạo nhãn {systemtag}",
    "%1$s created system tag %2$s" : "%1$s đã tạo nhãn %2$s",
    "{actor} created system tag {systemtag}" : "{actor} đã tạo nhãn {systemtag}",
    "You deleted system tag %1$s" : "Bạn đã xóa nhãn %1$s",
    "You deleted system tag {systemtag}" : "Bạn đã xóa nhãn {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s đã xóa nhãn %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} đã xóa nhãn {systemtag}",
    "You updated system tag %2$s to %1$s" : "Bạn đã cập nhật nhãn %2$s to %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Bạn đã cập nhật nhãn {oldsystemtag} thành {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s đã cập nhật nhãn %3$s thành%2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} đã cập nhật nhãn {oldsystemtag} thành {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Bạn đã dán nhãn %2$s vào %1$s",
    "You added system tag {systemtag} to {file}" : "Bạn đã dán nhãn {systemtag} vào {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s đã dán nhãn %3$s vào %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} đã dán nhãn {systemtag} vào {file}",
    "You removed system tag %2$s from %1$s" : "Bạn đã xóa nhãn %2$s khỏi %1$s",
    "You removed system tag {systemtag} from {file}" : "Bạn đã xóa nhãn {systemtag} khỏi {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s đã xóa nhãn %3$s khỏi %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} đã xóa nhãn {systemtag} khỏi {file}",
    "%s (restricted)" : "%s (bị hạn chế)",
    "%s (invisible)" : "%s (vô hình)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Nhãn</strong> cho một tập tin đã được sửa đổi",
    "Tags" : "Nhãn",
    "Collaborative tags" : "Thẻ cộng tác",
    "Tagged files" : "Các tệp được dán nhãn",
    "Select tags to filter by" : "Chọn nhãn để lọc theo",
    "No tags found" : "Không tìm thấy nhãn",
    "Please select tags to filter by" : "Vui lòng chọn các nhãn để lọc theo",
    "No files found for the selected tags" : "Không tìm thấy tệp cho các nhãn đã chọn",
    "Create a new tag" : "Tạo một thẻ mới",
    "Name" : "Tên",
    "Public" : "Công khai",
    "Restricted" : "Bị giới hạn",
    "Invisible" : "Vô hình",
    "Delete" : "Xóa bỏ",
    "Reset" : "Đặt lại",
    "No files in here" : "Không có tệp ở đây",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi"
},
"nplurals=1; plural=0;");

==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/vi.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Tên thẻ đang trống",
    "Update" : "Cập nhật",
    "Create" : "Tạo",
    "Select tag …" : "Lựa chọn thẻ",
    "System tag %1$s added by the system" : "Thẻ hệ thống %1$s được hệ thống thêm vào",
    "Added system tag {systemtag}" : "Nhãn hệ thống được thêm vào {systemtag}",
    "Added system tag %1$s" : "Đã thêm nhãn hệ thống %1$s",
    "%1$s added system tag %2$s" : "%1$s đã thêm nhãn hệ thống %2$s",
    "{actor} added system tag {systemtag}" : "{actor} đã thêm nhãn hệ thống {systemtag}",
    "System tag %1$s removed by the system" : "Thẻ hệ thống %1$s được hệ thống xóa đi",
    "Removed system tag {systemtag}" : "Đã xóa nhãn hệ thống {systemtag}",
    "Removed system tag %1$s" : "Đã xóa nhãn hệ thống %1$s",
    "%1$s removed system tag %2$s" : "%1$s đã xóa nhãn hệ thống %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} đã xóa nhãn {systemtag}",
    "You created system tag %1$s" : "Bạn đã tạo nhãn %1$s",
    "You created system tag {systemtag}" : "Bạn đã tạo nhãn {systemtag}",
    "%1$s created system tag %2$s" : "%1$s đã tạo nhãn %2$s",
    "{actor} created system tag {systemtag}" : "{actor} đã tạo nhãn {systemtag}",
    "You deleted system tag %1$s" : "Bạn đã xóa nhãn %1$s",
    "You deleted system tag {systemtag}" : "Bạn đã xóa nhãn {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s đã xóa nhãn %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} đã xóa nhãn {systemtag}",
    "You updated system tag %2$s to %1$s" : "Bạn đã cập nhật nhãn %2$s to %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Bạn đã cập nhật nhãn {oldsystemtag} thành {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s đã cập nhật nhãn %3$s thành%2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} đã cập nhật nhãn {oldsystemtag} thành {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Thẻ hệ thống %2$s được hệ thống thêm vào %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Thẻ hệ thống {systemtag} được hệ thống thêm vào {file}",
    "You added system tag %2$s to %1$s" : "Bạn đã dán nhãn %2$s vào %1$s",
    "You added system tag {systemtag} to {file}" : "Bạn đã dán nhãn {systemtag} vào {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s đã dán nhãn %3$s vào %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} đã dán nhãn {systemtag} vào {file}",
    "System tag %2$s was removed from %1$s by the system" : "Thẻ hệ thống %2$s được hệ thống xóa khỏi %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Thẻ hệ thống {systemtag} được hệ thống xóa khỏi {file}",
    "You removed system tag %2$s from %1$s" : "Bạn đã xóa nhãn %2$s khỏi %1$s",
    "You removed system tag {systemtag} from {file}" : "Bạn đã xóa nhãn {systemtag} khỏi {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s đã xóa nhãn %3$s khỏi %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} đã xóa nhãn {systemtag} khỏi {file}",
    "%s (restricted)" : "%s (bị hạn chế)",
    "%s (invisible)" : "%s (vô hình)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Nhãn</strong> cho một tập tin đã được sửa đổi",
    "Tags" : "Nhãn",
    "Collaborative tags" : "Thẻ cộng tác",
    "Collaborative tagging functionality which shares tags among users." : "Chức năng gắn thẻ mang tính hợp tác, chia sẻ thẻ giữa những người dùng.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Chức năng gắn thẻ mang tính hợp tác, chia sẻ thẻ giữa những người dùng. Rất tuyệt đối với các nhóm.\n\t(Nếu bạn là người cung cấp có bản sao có nhiều người thuê, chúng tôi khuyên bạn vô hiệu hóa ứng dụng này vì các thẻ được chia sẻ.)",
    "This file has the tag {tag}" : "Tập tin này có nhãn {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tệp tin này có nhãn {firstTags} và {lastTag}",
    "Tagged files" : "Các tệp được dán nhãn",
    "Select tags to filter by" : "Chọn nhãn để lọc theo",
    "No tags found" : "Không tìm thấy nhãn",
    "Please select tags to filter by" : "Vui lòng chọn các nhãn để lọc theo",
    "No files found for the selected tags" : "Không tìm thấy tệp cho các nhãn đã chọn",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Các thẻ hợp tác là có sẵn cho tất cả người dùng. Các thẻ giới hạn có thể được người dùng nhìn thấy nhưng không thể được họ phân công. Các thẻ vô hình là dành cho việc sử dụng nội bộ, vì những người dùng không thể thấy hay phân công chúng.",
    "Create a new tag" : "Tạo một thẻ mới",
    "Name" : "Tên",
    "Public" : "Công khai",
    "Restricted" : "Bị giới hạn",
    "Invisible" : "Vô hình",
    "Delete" : "Xóa bỏ",
    "Reset" : "Đặt lại",
    "No files in here" : "Không có tệp ở đây",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi"
},
"nplurals=1; plural=0;");
